@@ -67,6 +67,21 @@ def insert_missing(update_df: pd.DataFrame, table_name: str, table_schema = None
     return filehelper.write_sql(table_name, insert_df, schema=schema_name, table_schema=table_schema)
 
 
+def delete_append(update_df: pd.DataFrame, table_name: str, table_schema = None, schema_name: str = None, filehelper = None):
+    filehelper = filehelper if filehelper is not None else Files
+    table_schema = table_schema if table_schema is not None else filehelper.read_table_schema(table_name, schema_name)
+
+    validated_df = table_schema.validate(update_df)
+
+    create_table_if_not_exists(table_name, table_schema, schema_name, filehelper)
+
+    current_df = filehelper.read_sql_table(table_name, schema=schema_name)
+    df = apply_delete_columns(current_df, validated_df, table_schema)
+    df = df.append(validated_df)
+
+    return filehelper.write_sql(table_name, df, schema=schema_name, table_schema=table_schema)
+
+
 def insert_one(item: dict, table_name: str, table_schema = None, skip_if_pk_match = False, schema_name: str = None, filehelper = None):
     filehelper = filehelper if filehelper is not None else Files
     table_schema = table_schema if table_schema is not None else filehelper.read_table_schema(table_name, schema_name)
