@@ -58,9 +58,13 @@ class Schema:
         return pd.DataFrame({key: pd.Series(dtype=dtype) for key, dtype in self.dtype_dict.items()})
 
     @property
-    def field_names(self):
+    def column_names(self):
         return [col for col in self.pandera.columns]
 
+    @property
+    def required_column_names(self):
+        return [col for col in self.pandera.columns if col.required]
+
     @property
     def dtype_dict(self):
         return {key: str(dtype) for key, dtype in self.pandera.dtypes.items()}
@@ -73,4 +77,10 @@ class Schema:
             raise SchemaException("Schema can only have one of delete columns or primary keys")
 
     def validate(self, df: pd.DataFrame):
+        if self.pandera.coerce:
+            df = self.reorder_columns(df)
+
         return self.pandera.validate(df)
+
+    def reorder_columns(self, df: pd.DataFrame):
+        return df[self.column_names]
