@@ -1,15 +1,18 @@
 import datetime
 import time
+from typing import Union
+
 
 class LoggerException(Exception):
     pass
 
 
 class Logger:
-    def __init__(self, do_print=True):
+    def __init__(self, do_print=True, name: Union[str, None] = None):
         self.messages = []
         self.do_print = do_print
         self.levels = ["ok", "fail", "warn", "info", "debug"]
+        self.name = name
 
     def pretty_print(self, message):
         level, timestamp, content = message
@@ -22,12 +25,15 @@ class Logger:
     def get_messages_on_level(self, wanted_level):
         return [(level, timestamp, content) for level, timestamp, content in self.messages if level == wanted_level]
 
-    def log(self, level: str, content: str):
+    def log(self, level: str, *messages):
+        content = " ".join([str(message) for message in messages])
+
         if level not in self.levels:
             level_string = ", ".join(self.levels)
             raise LoggerException(f"Unknown Log level {level}, should be one of {level_string}")
 
         timestamp = time.time()
+
         message = (level, timestamp, content)
         self.messages.append(message)
 
