@@ -2,7 +2,7 @@ import copy
 from sqlalchemy import MetaData, select, delete
 
 from jhdata.filehelper import *
-from jhdata.data_tools.database import create_table_if_not_exists, upsert, insert_one
+from jhdata.data_tools.database import create_table_if_not_exists, insert_missing, insert_one
 from jhdata.dates import current_timestamp
 
 
@@ -50,6 +50,8 @@ class RequestQueue:
         return self.filehelper.sql(statement)
 
     def insert_many(self, items):
+        DF_THRESHOLD = 10
+
         print(items[:3])
         items_parsed = [{
             "table_name": item["table_name"],
@@ -58,14 +60,19 @@ class RequestQueue:
             "requested_at": current_timestamp()
         } for item in items]
 
-        for item in items_parsed:
-            insert_one(
-                item,
-                self.table_name,
-                schema_name=self.schema,
-                table_schema=self.request_queue_schema,
-                skip_if_pk_match=True
-            )
+        if len(items_parsed) < DF_THRESHOLD:
+            for item in items_parsed:
+                insert_one(
+                    item,
+                    self.table_name,
+                    schema_name=self.schema,
+                    table_schema=self.request_queue_schema,
+                    skip_if_pk_match=True
+                )
+        else:
+            self.filehelper.logger.info(f"Queuing in bulk {len(items_parsed)} items")
+            item_df = pd.DataFrame(items_parsed)
+            insert_missing(item_df, self.table_name, schema_name=self.schema, table_schema=self.request_queue_schema)
 
     def insert_one(self, table_name: str, metadata: dict, priority: int = 0):
         return self.insert_many([
